@@ -19,14 +19,14 @@ public:
 private:
     Ui::MainWindow *ui;
     SabConnector sc;
-    QMenu *menuSettings;
     QString ucfirst(const QString);
 
 private slots:
     void on_pbHistory_clicked();
-    void on_pbSettings_clicked();
     void on_pbAdd_clicked();
     void on_pbRefresh_clicked();
+    void showAbout();
+    void showSettings();
 
 public slots:
     void updateLabel(QString, QString);
