@@ -4,7 +4,9 @@
 #include <QXmlStreamReader>
 #include <QEventLoop>
 #include <QFile>
+#include <QFileInfo>
 #include <QDomDocument>
+#include <QUuid>
 
 SabConnector::SabConnector()
 {
@@ -93,6 +95,11 @@ void SabConnector::finishedStatus(QNetworkReply* reply)
 {
     QByteArray bytes = reply->readAll();  // bytes
 
+    if(bytes.at(0)=='o' && bytes.at(1)=='k') // in case of file upload, there will be no XML
+    {
+        emit errorOccured("File upload succeeded.");
+        return;
+    }
     QString data(bytes); // string
     qDebug() << "finishedStatus:\n"+data;
     QMap<QString,QMap<QString,QString > > downloads;
@@ -210,7 +217,6 @@ void SabConnector::finishedStatus(QNetworkReply* reply)
            emit errorOccured(reply->errorString());
     }
 
-    //delete reply;
     qDebug() <<  "Done with func";
 }
 
@@ -227,23 +233,67 @@ QString SabConnector::getUrlNoXML(QString mode)
 
 void SabConnector::addNZB(QString filename)
 {
+    emit errorOccured("Uploading file...<br>Please be patient.");
+    //http://blog.ilric.org/2010/11/20/qt-http-post-multi-partupload/
+
     qDebug() << "addNZB "+filename;
-    QString a = getUrl(QString("addfile"));
+    //QString a = getUrl(QString("addfile"));
+    QString a = QString("http://").append(settingsobj->getAdress().append(":").append(QString::number(settingsobj->getPort())).append("/tapi"));
     QUrl url(a);
     qDebug() << "url: "+a;
     QNetworkRequest qnr(url);
     QByteArray qba;
     QFile f(filename);
-    //qba.append("name=");
-    //QString boundary("---------------------------7d934a10503cc");
-    /*QString crlf(0x0d);
-    crlf.append(0x0a);
+    QFileInfo finfo(filename);
 
-    qba.append("--" + boundary + crlf + "Content-Disposition: form-data; name=\"nzbfile\"");
-    qba.append("filename=\"file1.rar\"");
-    qba.append(crlf + "Content-Type: Application/Octet" + crlf + crlf);
+    if(finfo.suffix().toLower()=="nzb")
+    {// zip it to save A LOT of traffic
+
+    }
+
+    f.open(QIODevice::ReadOnly);
+
+    QString boundary("---------------------------"+QUuid::createUuid());
+
+    qba.append("--"+boundary+"\r\n"); //start boundary
+
+    //the api key:
+    qba.append("Content-Disposition: form-data; name=\"apikey\"\r\n");
+    qba.append("Content-Type: Content-Type: text/plain\r\n\r\n");
+    qba.append(settingsobj->getAPIkey()+"\r\n");
+    qba.append("--"+boundary+"\r\n");
+
+    //the mode to make clear we are uploading an file
+    qba.append("Content-Disposition: form-data; name=\"mode\"\r\n");
+    qba.append("Content-Type: Content-Type: text/plain\r\n\r\n");
+    qba.append("addfile\r\n");
+    qba.append("--"+boundary+"\r\n");
+
+    //the catagory TODO make customizable
+    qba.append("Content-Disposition: form-data; name=\"cat\"\r\n");
+    qba.append("Content-Type: Content-Type: text/plain\r\n\r\n");
+    qba.append("Default\r\n");
+    qba.append("--"+boundary+"\r\n");
+
+    //priority? TODO make customizable
+    qba.append("Content-Disposition: form-data; name=\"pp\"\r\n");
+    qba.append("Content-Type: Content-Type: text/plain\r\n\r\n");
+    qba.append("-1\r\n");
+    qba.append("--"+boundary+"\r\n");
+
+    //the file to upload
+    qba.append("Content-Disposition: form-data; name=\"name\"; filename=\""+finfo.fileName()+"\"\r\n");
+    qba.append("Content-Type: application/octet-stream\r\n\r\n");
     qba.append(f.readAll());
-    qba.append(crlf);*/
+    qba.append("\r\n--"+boundary+"--\r\n\r\n");
+
+    QString concatenated = settingsobj->getUsername()+":"+settingsobj->getPassword();
+    qnr.setRawHeader("Authorization", "Basic " + QByteArray(concatenated.toAscii()).toBase64());
+
+    qnr.setRawHeader("Content-Type", QString("multipart/form-data; boundary=" + boundary).toAscii());
+    qnr.setRawHeader("Content-Length", QString::number(qba.length()).toAscii());
+    //qnr.setRawHeader("Accept-Encoding", QString("gzip,deflate").toAscii());
 
     /*QNetworkReply * reply =*/ nam->post(qnr,qba);
+    f.close();
 }
